#
# spec file for package nwg-drawer
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nwg-drawer
Version:        0.6.3
Release:        1.2
Summary:        Wlroots application drawer
License:        MIT
URL:            https://github.com/nwg-piotr/nwg-drawer
Source:         https://github.com/nwg-piotr/nwg-drawer/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  make
BuildRequires:  golang(API) >= 1.23
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk-layer-shell-0)
BuildRequires:  pkgconfig(pango)

%description
Application drawer for wlroots-based Wayland compositors.

%prep
%autosetup -p1 -a1

%build
go build -v -o bin/%{name} -mod=vendor -buildmode=pie

%install
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -r desktop-directories %{buildroot}%{_datadir}/%{name}
cp -r img %{buildroot}%{_datadir}/%{name}
install -m644 drawer.css %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_bindir}
install -m755 bin/%{name} %{buildroot}%{_bindir}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/%{name}

%changelog
* Thu Jan 30 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 0.6.3.
  Changelog: https://github.com/nwg-piotr/nwg-drawer/releases/tag/v0.6.3
  - Fixed crash when deleting or backspacing all text from the search field #152 (only happened with the `-nocats` flag).
* Wed Jan 22 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 0.6.2.
  Changelog: https://github.com/nwg-piotr/nwg-drawer/releases/tag/v0.6.2
  * Fixed crash on entering a :command in the search box while running with the -nocats argument; closes #151.
- Changes from version 0.6.1:
  Changelog: https://github.com/nwg-piotr/nwg-drawer/releases/tag/v0.6.1
  * Added the ability to run shell commands directly from the search box - just use colon (:) as the first character; #143 by @rienovie;
  * added optional close button for touch devices (use the -closebtn left|right flag); #148 by @caffeine01;
  * added size request for powerButtonsWrapper; closes #149;
  * dependencies updated.
* Mon Dec  2 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 0.6.0.
  * Migrated to diamondburned GTK bindings, bye bye gotk3 library (but we are still on GTK3);
  * disallowed userDirButton parent selection (makes possible keyboard usage on directory names);
  * desktopEntries sorted case insensitive.
* Sat Oct 26 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 0.5.2.
  Changelog: https://github.com/nwg-piotr/nwg-drawer/releases/tag/v0.5.2
  - gtk-layer-shell namespace set to nwg-drawer;
  - #math-label CSS ID added to the math result label, closes #134;
  - README.md updated by @msmafra and myself;
  - dependencies updated.
* Wed Oct 16 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 0.5.1.
  * Added calculations in the search box.
- Changes from version 0.5.0:
  * updated gotk3 version; #127 by @mattkae;
  * updated other dependencies;
  * added support for riverctl spawn (-wm flag);
  * fixed obsolete code in the hyprctl function;
  * fixed mapping output->monitor (a workaround to a GTK3 bug).
- Changes from version 0.5.0:
  * Added the -pbuseicontheme flag; closes #122.
- Changes from version 0.4.8:
  * Added -open and -close flags and signals; @121 by @rrrrrm;
  * dependencies updated, except for gotk3 0.6.4, that refuses to build.
* Fri Apr 19 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 0.4.7.
  Changelog:
  * The /usr/share/nwg-drawer path un-hardcoded, will be searched in XDG_DATA_DIRS from now on; closes #115;
  * if power bar present, pressing the Tab key will move focus to its first button;
  * go 1.21 -> 1.22;
  * golang.org/x/sys v0.16.0 -> v0.17.0.
* Wed Nov  8 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 0.4.0.
  * added -wm sway | hyprland argument; if set, programs will be launched via either swaymsg exec <command> or hyprctl dispatch exec <command>; #101, #102 by @gouvinb
  * golang and libraries versions updated
- Update to version 0.3.8.
  * added -k argument to set GTK layer shell Keyboard interactivity to 'on-demand' mode #95 by @trinitronx
  * added -ft argument to Force Theme for libadwaita/GTK4 apps, by adding 'GTK_THEME=' environment variable #96
* Mon May 15 2023 Lukas Müller <expeehaa@outlook.com>
- Create initial package with version 0.3.8.
